var indexSectionsWithContent =
{
  0: ":abcdefghijklmnopqrstuvwxyz~",
  1: "abcdefghilmnopstuvw",
  2: "cimst",
  3: "abcdefghilmoprstuvw",
  4: "abcdefghiklmnopqrstuvwxy~",
  5: "abcdefghiklmnoprstuvw",
  6: "cdfimstu",
  7: "abcdefgiklmprstvx",
  8: "abcdefghijklmnopqrstuvwxyz",
  9: ":fgimotw",
  10: "ct",
  11: "abcdefilnopstu"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "namespaces",
  3: "files",
  4: "functions",
  5: "variables",
  6: "typedefs",
  7: "enums",
  8: "enumvalues",
  9: "related",
  10: "defines",
  11: "pages"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Namespaces",
  3: "Files",
  4: "Functions",
  5: "Variables",
  6: "Typedefs",
  7: "Enumerations",
  8: "Enumerator",
  9: "Friends",
  10: "Macros",
  11: "Pages"
};

